@@ -107,7 +107,7 @@ impl<'de> Deserialize<'de> for TitleTypeFromImdb {
 		let s: &str = Deserialize::deserialize(deserializer)?;
 		Ok(match s {
 			"short" => Self::Short,
-			"episode" | "tvEpisode" => Self::Episode,
+			"episode" | "tvEpisode" | "tvPilot" => Self::Episode,
 			"movie" | "tvMovie" => Self::Movie,
 			"tvSeries" | "tvMiniSeries" => Self::TVSeries,
 			"tvShort" => Self::TVShort,
@@ -117,7 +117,7 @@ impl<'de> Deserialize<'de> for TitleTypeFromImdb {
 			"audiobook" => Self::Audiobook,
 			"radioSeries" => Self::RadioSeries,
 			"radioEpisode" => Self::RadioEpisode,
-			s => return Err(serde::de::Error::invalid_value(Unexpected::Str(&s), &"'short', 'episode', 'tvEpisode', 'movie', 'tvMovie', 'tvSeries', 'tvMiniSeries', 'tvShort', 'tvSpecial', 'video', 'videoGame', 'audiobook', 'radioSeries', 'radioEpisode'"))
+			s => return Err(serde::de::Error::invalid_value(Unexpected::Str(&s), &"'short', 'episode', 'tvEpisode', 'tvPilot', 'movie', 'tvMovie', 'tvSeries', 'tvMiniSeries', 'tvShort', 'tvSpecial', 'video', 'videoGame', 'audiobook', 'radioSeries', 'radioEpisode'"))
 		})
 	}
 }
